<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Main Slider
 *
 * 
 *
 * @since 1.0.0
 */
class Main_Slider_Knjiznice extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'knjiznice-slider';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Knjižnice Slider', 'knjiznice' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'general' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'knjiznice-slider' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Nastavitve', 'knjiznice' ),
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label' => __( 'Samodejno predvajanje', 'knjiznice' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Da', 'knjiznice' ),
				'label_off' => __( 'Ne', 'knjiznice' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->add_control(
			'slider_speed',
			[
				'label' => __( 'Hitrost predvajanja (v sekundah)', 'knjiznice' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 100,
				'step' => 1,
				'default' => 6,
			]
		);
		$this->add_control(
			'slider_height',
			[
				'label' => __( 'Višina sliderja (v px)', 'knjiznice' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 100,
				'max' => 1000,
				'step' => 1,
				'default' => 520,
			]
		);

		$this->end_controls_section();


		
	
		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Elementi', 'knjiznice' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'list_title', [
				'label' => __( 'Naslov', 'knjiznice' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Naslov' , 'plugin-domain' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'hidden',
			[
				'label' => __( 'Skrito', 'knjiznice' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Da', 'knjiznice' ),
				'label_off' => __( 'Ne', 'knjiznice' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$repeater->add_control(
			'hide_content',
			[
				'label' => __( 'Skrij vsebino', 'knjiznice' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Da', 'knjiznice' ),
				'label_off' => __( 'Ne', 'knjiznice' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$repeater->add_control(
			'list_content', [
				'label' => __( 'Opis', 'knjiznice' ),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
				'default' => __( 'Opis' , 'knjiznice' ),
				'show_label' => true,
			]
		);
		
		$repeater->add_control(
			'list_image',
			[
				'label' => __( 'Slika ozadja', 'knjiznice' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);
		$repeater->add_control(
			'list_url',
			[
				'label' => __( 'Povezava', 'knjiznice' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://www.vasa-povezava.si', 'knjiznice' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => false,
					'nofollow' => false,
				],
			]
		);
		$repeater->add_control(
			'list_url_text',
			[
				'label' => __( 'Tekst povezava', 'knjiznice' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Preberi več', 'knjiznice' ),
			]
		);
		$repeater->add_control(
			'list_container_position',
			[
				'label' => __( 'Pozicija ozadja', 'knjiznice' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'levo',
				'options' => [
					'lefo'  => __( 'Levo', 'knjiznice' ),
					'desno' => __( 'Desno', 'knjiznice' ),
				],
			]
		);
		
		$repeater->add_control(
			'list_background_color',
			[
				'label' => __( 'Barva ozadja', 'knjiznice' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Core\Schemes\Color::get_type(),
					'value' => \Elementor\Core\Schemes\Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .title' => 'color: {{VALUE}}',
				],
			]
		);
		$repeater->add_control(
			'list_text_color',
			[
				'label' => __( 'Barva pisave', 'knjiznice' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Core\Schemes\Color::get_type(),
					'value' => \Elementor\Core\Schemes\Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .title' => 'color: {{VALUE}}',
				],
			]
		);
		$repeater->add_control(
			'list_button_color',
			[
				'label' => __( 'Barva gumba', 'knjiznice' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Core\Schemes\Color::get_type(),
					'value' => \Elementor\Core\Schemes\Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .title' => 'color: {{VALUE}}',
				],
			]
		);
		$repeater->add_control(
			'list_button_text_color',
			[
				'label' => __( 'Barva pisave gumba', 'knjiznice' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Core\Schemes\Color::get_type(),
					'value' => \Elementor\Core\Schemes\Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .title' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'list',
			[
				'label' => __( 'Seznam elementov', 'knjiznice' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'list_title' => __( 'Naslov #1', 'knjiznice' ),
						'list_content' => __( 'Opis', 'knjiznice' ),
					],
				],
				'title_field' => '{{{ list_title }}}',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		include(dirname(__FILE__).'/../default.php');
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<div class="title">
			{{{ settings.title }}}
		</div>
		<?php
	}
}