<?php
/**
 * Knjiznice Theme Customizer
 *
 * @package Knjiznice
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function knjiznice_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'knjiznice_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'knjiznice_customize_partial_blogdescription',
		) );
	}
	
	/* custom colors*/	
	$wp_customize->add_setting( 'text_color', array(
      'default'   => '#333333',
      'transport' => 'refresh',
    ));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'text_color', array(
		'label'   => esc_html__( 'Barva pisave', 'theme' ),
		'section' => 'colors'
	)));
	
	$wp_customize->add_setting( 'main_color', array(
      'default'   => '#FFA81B',
      'transport' => 'refresh',
    ));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'main_color', array(
		'label'   => esc_html__( 'Glavna barva', 'theme' ),
		'section' => 'colors'
	)));
	
	$wp_customize->add_setting( 'inverse_color', array(
      'default'   => '#ffffff',
      'transport' => 'refresh',
    ));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'inverse_color', array(
		'label'   => esc_html__( 'Inverzna barva', 'theme' ),
		'section' => 'colors'
	)));
	

	$wp_customize->add_section( 'custom_settings_knjiznice' , array(
		'title'    => __('Dodatne nastavitve','knjiznice'),
		'priority' => 500
	));


	$wp_customize->add_setting( 'knjiznice_google_api_key', array(
		 'default' => ''
	));

	$wp_customize->add_control( new WP_Customize_Control(
	    $wp_customize,
		'custom_settings_knjiznice',
		    array(
		        'label'    => __( 'Google Api Key', 'knjiznice' ),
		        'section'  => 'custom_settings_knjiznice',
		        'settings' => 'knjiznice_google_api_key',
		        'type'     => 'text'
		    )
	    )
	);
	
}
add_action( 'customize_register', 'knjiznice_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function knjiznice_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function knjiznice_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function knjiznice_customize_preview_js() {
	wp_enqueue_script( 'knjiznice-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'knjiznice_customize_preview_js' );
