<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Knjiznice
 */

if ( ! function_exists( 'knjiznice_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function knjiznice_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
			/* translators: %s: post date. */
			esc_html_x( 'Objavljeno %s', 'post date', 'knjiznice' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);

		echo '<span class="posted-on">' . $posted_on . '</span>'; // WPCS: XSS OK.

	}
endif;

if ( ! function_exists( 'knjiznice_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function knjiznice_posted_by() {
		$byline = sprintf(
			/* translators: %s: post author. */
			esc_html_x( 'by %s', 'post author', 'knjiznice' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);

		echo '<span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

	}
endif;

if ( ! function_exists( 'knjiznice_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function knjiznice_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'knjiznice' ) );
			if ( $categories_list ) {
				/* translators: 1: list of categories. */
				printf( '<div class="cat-links"><strong>' . __('Kategorije', 'knjiznice') . '</strong>: ' . esc_html__( '%1$s', 'knjiznice' ) . '</div>', $categories_list ); // WPCS: XSS OK.
			}

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'knjiznice' ) );
			if ( $tags_list ) {
				/* translators: 1: list of tags. */
				printf( '<div class="tags-links"><strong>' . __('Oznake', 'knjiznice') . '</strong>: ' . esc_html__( '%1$s', 'knjiznice' ) . '</div>', $tags_list ); // WPCS: XSS OK.
			}
		}

		/*if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link(
				sprintf(
					wp_kses(
						__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'knjiznice' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				)
			);
			echo '</span>';
		}*/
		if (is_single()) {
			edit_post_link(
				sprintf(
					wp_kses(
						/* translators: %s: Name of current post. Only visible to screen readers */
						__( 'Uredi <span class="screen-reader-text">%s</span>', 'knjiznice' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				),
				'<span class="edit-link">',
				'</span>'
			);
		}
	}
endif;

if (!function_exists( 'knjiznice_post_thumbnail')):
	function knjiznice_post_thumbnail($size) {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}
		?>
		<?php if (is_singular()) : ?>
			<?php the_post_thumbnail($size); ?>
		<?php else: ?>
			<a href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
				<?php the_post_thumbnail($size, array('alt' => the_title_attribute(array('echo' => false)))); ?>
			</a>
		<?php
		endif;
	}
endif;


if (!function_exists('knjiznice_post_dogodki_meta')):
	function knjiznice_post_dogodki_meta() {
		if (!post_type_exists('dogodki')) return;
		?>
		<div class="entry-meta-inner">
			<?php
				$categories = get_the_terms(get_the_ID(), 'kategorije-dogodki');
				$categories2 = array();
				if (!empty($categories)) foreach ($categories as $category) {
					$categories2[] = '<a href="'.get_term_link($category).'">'.$category->name.'</a>';
				}
			?>
			<?php if (!empty($categories2)) : ?>
				<div><strong><?php echo __('Kategorija', 'knjiznice'); ?></strong><br /><?php echo implode(', ', $categories2) ?></div>
			<?php endif; ?>
			<?php if (!empty(get_field("dogodek_lokacija"))) : ?>
				<div><strong><?php echo __('Lokacija', 'knjiznice'); ?></strong><br /><?php echo __(get_field("dogodek_lokacija"), 'knjiznice'); ?></div>
			<?php endif; ?>
			<?php if (!empty(get_field("dogodek_namenjeno"))) : ?>
				<?php $namenjeno_array = get_field("dogodek_namenjeno"); ?>
				<?php foreach ($namenjeno_array as &$namenjeno) $namenjeno = __($namenjeno, 'knjiznice');  ?> 
				<div><strong><?php echo __('Namenjeno', 'knjiznice'); ?></strong><br /><?php echo implode(', ', $namenjeno_array); ?></div>
			<?php endif; ?>
			<div><strong><?php echo __('Začetek', 'knjiznice'); ?></strong><br /><?php echo get_field("dogodek_zacetek")["datum"]; ?> <?php echo __('ob', 'knjiznice'); ?> <?php echo get_field("dogodek_zacetek")["ura"]; ?></div>
			<?php if (!empty(get_field("dogodek_vecdnevni"))) : ?>
				<div><strong><?php echo __('Konec', 'knjiznice'); ?></strong><br /><?php echo get_field("dogodek_konec")["datum"]; ?> <?php echo __('ob', 'knjiznice'); ?> <?php echo get_field("dogodek_konec")["ura"]; ?></div>
			<?php endif; ?>
			<?php if (!empty(get_field("dogodek_kraj"))) : ?>
				<div><strong><?php echo __('Kraj', 'knjiznice'); ?></strong><br /><?php echo __(get_field("dogodek_kraj"), 'knjiznice'); ?></div>
			<?php endif; ?>
			<?php if (!empty(get_field("dogodek_kontakt_oseba"))) : ?>
				<div><strong><?php echo __('Kontaktna oseba', 'knjiznice'); ?></strong><br /><?php echo get_field("dogodek_kontakt_oseba"); ?></div>
			<?php endif; ?>
			<?php if (!empty(get_field("dogodek_telefon"))) : ?>
				<div><strong><?php echo __('Telefon', 'knjiznice'); ?></strong><br /><?php echo get_field("dogodek_telefon"); ?></div>
			<?php endif; ?>
			<div><strong><?php echo __('Objavil', 'knjiznice'); ?></strong><br /><?php echo get_the_author(); ?></div>
		</div>
	<?php
	}
endif;

if (!function_exists('knjiznice_post_knjige_meta')):
	function knjiznice_post_knjige_meta() {
		if (!post_type_exists('knjige')) return;
		?>
		<div class="entry-meta-inner">
			<?php
				$categories = get_the_terms(get_the_ID(), 'zvrsti-knjig');
				$categories2 = array();
				if (!empty($categories)) foreach ($categories as $category) {
					$categories2[] = '<a href="'.get_term_link($category).'">'.$category->name.'</a>';
				}
			?>
			<?php if (!empty($categories2)) : ?>
				<div><strong><?php echo __('Zvrst', 'knjiznice'); ?></strong><br /><?php echo implode(', ', $categories2) ?></div>
			<?php endif; ?>
			<?php if (!empty(get_field("knjiga_avtor"))) : ?>
				<div><strong><?php echo __('Avtor', 'knjiznice'); ?></strong><br /><?php echo get_field("knjiga_avtor"); ?></div>
			<?php endif; ?>
			<?php if (!empty(get_field("knjiga_soavtor"))) : ?>
				<div><strong><?php echo __('Soavtor', 'knjiznice'); ?></strong><br /><?php echo get_field("knjiga_soavtor"); ?></div>
			<?php endif; ?>
			<?php if (!empty(get_field("knjiga_isbn"))) : ?>
				<div><strong><?php echo __('ISBN', 'knjiznice'); ?></strong><br /><?php echo get_field("knjiga_isbn"); ?></div>
			<?php endif; ?>
			<?php if (!empty(get_field("knjiga_zaloznik"))) : ?>
				<div><strong><?php echo __('Založnik', 'knjiznice'); ?></strong><br /><?php echo get_field("knjiga_zaloznik"); ?></div>
			<?php endif; ?>
			<?php if (!empty(get_field("knjiga_jezik"))) : ?>
				<div><strong><?php echo __('Jezik', 'knjiznice'); ?></strong><br /><?php echo get_field("knjiga_jezik"); ?></div>
			<?php endif; ?>
			<?php if (!empty(get_field("knjiga_vrsta_nabave"))) : ?>
				<div><strong><?php echo __('Vrsta nabave', 'knjiznice'); ?></strong><br /><?php echo get_field("knjiga_vrsta_nabave"); ?></div>
			<?php endif; ?>
			<?php if (!empty(get_field("knjiga_povezava_cobiss"))) : ?>
				<div><strong><?php echo __('Povezava do COBISS', 'knjiznice'); ?></strong><br /><?php echo get_field("knjiga_povezava_cobiss"); ?></div>
			<?php endif; ?>
			<div><strong><?php echo __('Objavil', 'knjiznice'); ?></strong><br /><?php echo get_the_author(); ?></div>
		</div>
	<?php
	}
endif;

if (!function_exists('knjiznice_post_enote_meta')):
	function knjiznice_post_enote_meta() {
		if (!post_type_exists('enote')) return;
		?>
		<div class="entry-meta-inner">
			<?php if (!empty(get_field("enota_vrsta")) && false) : ?>
				<div><strong><?php echo __('Vrsta enote', 'knjiznice'); ?></strong><br /><?php echo get_field("enota_vrsta"); ?></div>
			<?php endif; ?>
			<?php if (!empty(get_field("enota_vodja"))) : ?>
				<div><strong><?php echo __('Vodja', 'knjiznice'); ?></strong><br /><?php echo get_field("enota_vodja"); ?></div>
			<?php endif; ?>
			<?php if (!empty(get_field("enota_email_vodja"))) : ?>
				<div><strong><?php echo __('E-mail vodja', 'knjiznice'); ?></strong><br /><a href="mailto:<?php echo get_field("enota_email_vodja"); ?>"><?php echo get_field("enota_email_vodja"); ?></a></div>
			<?php endif; ?>
			<?php if (!empty(get_field("enota_email"))) : ?>
				<div><strong><?php echo __('E-mail enote', 'knjiznice'); ?></strong><br /><a href="mailto:<?php echo get_field("enota_email"); ?>"><?php echo get_field("enota_email"); ?></a></div>
			<?php endif; ?>
			<?php if (!empty(get_field("enota_telefon"))) : ?>
				<div><strong><?php echo __('Telefon', 'knjiznice'); ?></strong><br /><?php echo get_field("enota_telefon"); ?></div>
			<?php endif; ?>
			<div class="special-services"><strong><?php echo __('Dostopnost', 'knjiznice'); ?></strong><br />
				<?php if (get_field('enota_posebne_storitve_invalidi')) : ?><i title="<?php echo __('Dostop za invalide', 'knjiznice'); ?>" class="fa fa-wheelchair" aria-hidden="true"></i><?php endif; ?>
				<?php if (get_field('enota_posebne_storitve_indukcijska')) : ?><img title="<?php echo __('Indukcijska zanka', 'knjiznice'); ?>" alt="indukcijska zanka" src="/wp-content/themes/knjiznice/images/tc-icons/hearing-loop.jpg" style="width:20px; height:auto;" /><?php endif; ?>
				<?php if (get_field('enota_posebne_storitve_dvigalo')) : ?><img title="<?php echo __('Dvigalo', 'knjiznice'); ?>" alt="dvigalo" src="/wp-content/themes/knjiznice/images/tc-icons/lift.jpg" style="width:17px; height:auto;" /><?php endif; ?>
				<?php if (get_field('enota_posebne_storitve_lupa')) : ?><img title="<?php echo __('Elektronska lupa', 'knjiznice'); ?>" alt="elektronska lupa" src="/wp-content/themes/knjiznice/images/tc-icons/magnifier.jpg" style="width:20px; height:auto;" /><?php endif; ?>
				<?php if (get_field('enota_posebne_storitve_wifi')) : ?><img title="<?php echo __('Brezžično omrežje', 'knjiznice'); ?>" alt="brezžično omrežje" src="/wp-content/themes/knjiznice/images/tc-icons/wifi.jpg" style="width:20px; height:auto;" /><?php endif; ?>
			</div>
		</div>
	<?php
	}
endif;

if (!function_exists('knjiznice_post_enote_lokacija_meta')):
	function knjiznice_post_enote_lokacija_meta() {
		if (!post_type_exists('enote')) return;
		?>
		<div class="entry-meta-inner">
			<?php if (!empty(get_field("enota_lokacija")) && !empty(get_field("enota_lokacija")["lat"])) : ?>
				<div id="enota-gmap"></div>
				<input class="enota-location-map" type="hidden" lat="<?php echo get_field("enota_lokacija")["lat"]; ?>" lng="<?php echo get_field("enota_lokacija")["lng"]; ?>" title="<?php the_title(); ?>" />
			<?php endif; ?>
			<?php if (!empty(get_field("enota_naslov"))) : ?>
				<div><?php echo get_field("enota_naslov"); ?></div>
			<?php endif; ?>
			<?php if (!empty(get_field("enota_lokacija")) && !empty(get_field("enota_lokacija")["lat"])) : ?>
				<p><a href="https://www.google.com/maps/dir/?api=1&destination=<?php echo get_field("enota_lokacija")["lat"]; ?>,<?php echo get_field("enota_lokacija")["lng"]; ?>" target="_blank"><?php echo __('Navodila za pot', 'knjiznice'); ?></a></p>
			<?php endif; ?>
		</div>
	<?php
	}
endif;

if (!function_exists('knjiznice_post_enote_delovni_meta')):
	function knjiznice_post_enote_delovni_meta() {
		if (!post_type_exists('enote')) return;
		
		$weekdays = array('nedelja', 'ponedeljek', 'torek', 'sreda', 'cetrtek', 'petek', 'sobota');
		$weekdaysCap = array(__('Nedelja', 'knjiznice'), __('Ponedeljek', 'knjiznice'), __('Torek', 'knjiznice'), __('Sreda', 'knjiznice'), __('Četrtek', 'knjiznice'), __('Petek', 'knjiznice'), __('Sobota', 'knjiznice'));
		$holidays = array();
		$holidays[] = date('Y-m-d', easter_date()+(3600*get_option('gmt_offset')));
		$holidays[] = date('Y-m-d', easter_date()+86400+(3600*get_option('gmt_offset')));
		$holidays[] = date('Y').'-01-01';
		$holidays[] = date('Y').'-01-02';
		$holidays[] = date('Y').'-02-08';
		$holidays[] = date('Y').'-04-27';
		$holidays[] = date('Y').'-05-01';
		$holidays[] = date('Y').'-05-02';
		$holidays[] = date('Y').'-06-25';
		$holidays[] = date('Y').'-08-15';
		$holidays[] = date('Y').'-10-31';
		$holidays[] = date('Y').'-11-01';
		$holidays[] = date('Y').'-12-25';
		$holidays[] = date('Y').'-12-26';

		$today = date('Y-m-d', time() + (3600*get_option('gmt_offset')));
		$active = true;
		if (!empty(get_field("enota_je_poletni"))) {
			if ($today >= get_field("odpiralni_cas_poletni_enota_veljavnost_od") && $today <= get_field("odpiralni_cas_poletni_enota_veljavnost_do"))
				$active = false;
		}
		
		$weekday = (int) date('w', time() + (3600*get_option('gmt_offset')));
		$isHolidayToday = false;
		foreach ($holidays as $holiday) {
			if ($holiday == $today) $isHolidayToday = true;
		} 
		
		$openhourslist = array();
		$isOpenOnHoliday = !empty(get_field('odpiralni_cas_enota_prazniki'));
		
		for ($i = 0; $i<count($weekdays); $i++) {
			$openstatus = (bool) get_field('odpiralni_cas_enota_'.$weekdays[$i].'_odprto');
			
			$openhours = new stdClass;
			$openhours->day = $weekdaysCap[$i];
			$openhours->open = '';
			$openhours->close = '';
			$openhours->isOpen = false;
			$openhours->isHoliday = false;
			$openhours->today = false;
			if ($openstatus === true) {
				$openhours->open = get_field('odpiralni_cas_enota_'.$weekdays[$i].'_od');
				$openhours->close = get_field('odpiralni_cas_enota_'.$weekdays[$i].'_do');
				$openhours->isOpen = true;
			} 
			
			if ($i === $weekday) $openhours->today = true;
			
			if ($i > $weekday) {
				$next_day = date('Y-m-d', time() + (($i - $weekday) * 86400) + (3600*get_option('gmt_offset')));
				foreach ($holidays as $holiday) {
					if ($holiday == $next_day) $openhours->isHoliday = true;
				} 
			}
			$openhourslist[] = $openhours;
		}
		
		$openstatustoday = (bool) get_field('odpiralni_cas_enota_'.$weekdays[$weekday].'_odprto');
		$currentstatus = '<span class="closed">'.__('Zaprto', 'knjiznice').'</span>';
		if ($openstatustoday === true) {
			$currenttime = date('H:i:s', time() + (3600*get_option('gmt_offset')));
			$opentime = get_field('odpiralni_cas_enota_'.$weekdays[$weekday].'_od');
			$closetime = get_field('odpiralni_cas_enota_'.$weekdays[$weekday].'_do');
			
			if ($currenttime >= $opentime && $currenttime <= $closetime) {
				$currentstatus = '<span class="open">'.__('Odprto', 'knjiznice').'</span>';
			} 
			if ((strtotime($opentime) - strtotime($currenttime)) < 3600 && (strtotime($opentime) - strtotime($currenttime)) > 0) {
				$currentstatus = '<span class="delay">'.__('Kmalu se odpre', 'knjiznice').'</span>';
			} else if ((strtotime($closetime) - strtotime($currenttime)) < 3600 && (strtotime($closetime) - strtotime($currenttime)) > 0) {
				$currentstatus = '<span class="delay">'.__('Kmalu se zapre', 'knjiznice').'</span>';
			}
			
			if ($isHolidayToday === true && $isOpenOnHoliday === false) {
				$currentstatus = '<span class="closed">' . __('Zaprto', 'knjiznice') . ' (' . __('Praznik', 'knjiznice') . ')</span>';
				$currentstatus_php = 0;
			}
		}
		$openhourslist[] = array_shift($openhourslist);		
		?>
		<div class="entry-meta-inner">
			<div class="openhours <?php echo $active ? 'active':''; ?>">
				<div class="currenthours"><strong><?php echo __('Danes:', 'knjiznice'); ?> <?php echo $currentstatus; ?></strong></div>
				<div class="openhourslist">
					<table class="table table-striped table-hover">
					<?php foreach ($openhourslist as $openhours) : ?>
						<tr class="<?php echo $openhours->today === true ? 'istoday':''; ?>">
							<td><?php echo $openhours->day; ?></td>
							<?php if ($openhours->isOpen === true): ?>
								<?php if (($openhours->isHoliday === true && $isOpenOnHoliday === false) || ($isHolidayToday === true && $openhours->today === true && $isOpenOnHoliday === false)): ?>
									<td><?php echo __('Zaprto', 'knjiznice'); ?> (<?php echo __('Praznik', 'knjiznice'); ?>)</td>
								<?php else: ?>
									<td><?php echo $openhours->open; ?> - <?php echo $openhours->close; ?></td>
								<?php endif; ?>
							<?php else: ?>
								<td><?php echo __('Zaprto', 'knjiznice'); ?></td>
							<?php endif; ?>
						</tr>
					<?php endforeach; ?>
					</table>
				</div>
			</div>
		</div>
	<?php
	}
endif;

if (!function_exists('knjiznice_post_enote_delovni_poletni_meta')):
	function knjiznice_post_enote_delovni_poletni_meta() {
		if (!post_type_exists('enote')) return;
		
		$weekdays = array('nedelja', 'ponedeljek', 'torek', 'sreda', 'cetrtek', 'petek', 'sobota');
		$weekdaysCap = array(__('Nedelja', 'knjiznice'), __('Ponedeljek', 'knjiznice'), __('Torek', 'knjiznice'), __('Sreda', 'knjiznice'), __('Četrtek', 'knjiznice'), __('Petek', 'knjiznice'), __('Sobota', 'knjiznice'));
		$holidays = array();
		$holidays[] = date('Y-m-d', easter_date()+(3600*get_option('gmt_offset')));
		$holidays[] = date('Y-m-d', easter_date()+86400+(3600*get_option('gmt_offset')));
		$holidays[] = date('Y').'-01-01';
		$holidays[] = date('Y').'-01-02';
		$holidays[] = date('Y').'-02-08';
		$holidays[] = date('Y').'-04-27';
		$holidays[] = date('Y').'-05-01';
		$holidays[] = date('Y').'-05-02';
		$holidays[] = date('Y').'-06-25';
		$holidays[] = date('Y').'-08-15';
		$holidays[] = date('Y').'-10-31';
		$holidays[] = date('Y').'-11-01';
		$holidays[] = date('Y').'-12-25';
		$holidays[] = date('Y').'-12-26';

		$today = date('Y-m-d', time() + (3600*get_option('gmt_offset')));
		$active = false;
		if (!empty(get_field("enota_je_poletni"))) {
			if ($today >= get_field("odpiralni_cas_poletni_enota_veljavnost_od") && $today <= get_field("odpiralni_cas_poletni_enota_veljavnost_do"))
				$active = true;
		}
		
		$weekday = (int) date('w', time() + (3600*get_option('gmt_offset')));
		$isHolidayToday = false;
		foreach ($holidays as $holiday) {
			if ($holiday == $today) $isHolidayToday = true;
		} 
		
		$openhourslist = array();
		$isOpenOnHoliday = !empty(get_field('odpiralni_cas_poletni_enota_prazniki'));
		$closedAllDays = true;
		for ($i = 0; $i<count($weekdays); $i++) {
			$openstatus = (bool) get_field('odpiralni_cas_poletni_enota_'.$weekdays[$i].'_odprto');
			
			$openhours = new stdClass;
			$openhours->day = $weekdaysCap[$i];
			$openhours->open = '';
			$openhours->close = '';
			$openhours->isOpen = false;
			$openhours->isHoliday = false;
			$openhours->today = false;
			if ($openstatus === true) {
				$openhours->open = get_field('odpiralni_cas_poletni_enota_'.$weekdays[$i].'_od');
				$openhours->close = get_field('odpiralni_cas_poletni_enota_'.$weekdays[$i].'_do');
				$openhours->isOpen = true;
				$closedAllDays = false;
			} 
			
			if ($i === $weekday) $openhours->today = true;
			
			if ($i > $weekday) {
				$next_day = date('Y-m-d', time() + (($i - $weekday) * 86400) + (3600*get_option('gmt_offset')));
				foreach ($holidays as $holiday) {
					if ($holiday == $next_day) $openhours->isHoliday = true;
				} 
			}
			$openhourslist[] = $openhours;
		}
		
		$openstatustoday = (bool) get_field('odpiralni_cas_poletni_enota_'.$weekdays[$weekday].'_odprto');
		$currentstatus = '<span class="closed">'.__('Zaprto', 'knjiznice').'</span>';
		if ($openstatustoday === true) {
			$currenttime = date('H:i:s', time() + (3600*get_option('gmt_offset')));
			$opentime = get_field('odpiralni_cas_poletni_enota_'.$weekdays[$weekday].'_od');
			$closetime = get_field('odpiralni_cas_poletni_enota_'.$weekdays[$weekday].'_do');
			
			if ($currenttime >= $opentime && $currenttime <= $closetime) {
				$currentstatus = '<span class="open">'.__('Odprto', 'knjiznice').'</span>';
			} 
			if ((strtotime($opentime) - strtotime($currenttime)) < 3600 && (strtotime($opentime) - strtotime($currenttime)) > 0) {
				$currentstatus = '<span class="delay">'.__('Kmalu se odpre', 'knjiznice').'</span>';
			} else if ((strtotime($closetime) - strtotime($currenttime)) < 3600 && (strtotime($closetime) - strtotime($currenttime)) > 0) {
				$currentstatus = '<span class="delay">'.__('Kmalu se zapre', 'knjiznice').'</span>';
			}
			
			if ($isHolidayToday === true && $isOpenOnHoliday === false) {
				$currentstatus = '<span class="closed">' . __('Zaprto', 'knjiznice') . ' (' . __('Praznik', 'knjiznice') . ')</span>';
				$currentstatus_php = 0;
			}
		}
		$openhourslist[] = array_shift($openhourslist);		
		?>
		<div class="entry-meta-inner">
			<div class="openhours <?php echo $active ? 'active':''; ?>">
				<?php if (!empty(get_field('odpiralni_cas_poletni_enota_veljavnost_od')) && !empty(get_field('odpiralni_cas_poletni_enota_veljavnost_do'))) : ?>
					<div class="summertimeinterval">
						<strong><?php echo __('Trajanje poletnega odpiralnega časa:', 'knjiznice'); ?></strong><br />
						<?php echo date('d.m.Y', strtotime(get_field('odpiralni_cas_poletni_enota_veljavnost_od'))); ?>
						-
						<?php echo date('d.m.Y', strtotime(get_field('odpiralni_cas_poletni_enota_veljavnost_do'))); ?>
					</div>
				<?php endif; ?>
				<div class="currenthours"><strong><?php echo __('Danes:', 'knjiznice'); ?> <?php echo $currentstatus; ?></strong></div>
				<div class="openhourslist">
					<table class="table table-striped table-hover">
					<?php if ($closedAllDays === true) : ?>
						<tr>
							<td><?php echo __('Vse dni', 'knjiznice'); ?></td>
							<td><?php echo __('Zaprto', 'knjiznice'); ?></td>
						</tr>
					<?php else: ?>
						<?php foreach ($openhourslist as $openhours) : ?>
							<tr class="<?php echo $openhours->today === true ? 'istoday':''; ?>">
								<td><?php echo $openhours->day; ?></td>
								<?php if ($openhours->isOpen === true): ?>
									<?php if (($openhours->isHoliday === true && $isOpenOnHoliday === false) || ($isHolidayToday === true && $openhours->today === true && $isOpenOnHoliday === false)): ?>
										<td><?php echo __('Zaprto', 'knjiznice'); ?> (<?php echo __('Praznik', 'knjiznice'); ?>)</td>
									<?php else: ?>
										<td><?php echo $openhours->open; ?> - <?php echo $openhours->close; ?></td>
									<?php endif; ?>
								<?php else: ?>
									<td><?php echo __('Zaprto', 'knjiznice'); ?></td>
								<?php endif; ?>
							</tr>
						<?php endforeach; ?>
					<?php endif; ?>
					</table>
				</div>
			</div>
		</div>
	<?php
	}
endif;